# pylint:disable=missing-module-docstring

from bo4e.enum.strenum import StrEnum


class Zaehlergroesse(StrEnum):
    """
    Auflistung möglicher Größen von Zählern
    """

    G2KOMMAP5 = "G2KOMMA5"  #: Gaszähler Größe G2.5
    G4 = "G4"  #: Gaszähler Größe G4
    G6 = "G6"  #: Gaszähler Größe G6
    G10 = "G10"  #: Gaszähler Größe G10
    G16 = "G16"  #: Gaszähler Größe G16
    G25 = "G25"  #: Gaszähler Größe G25
    G40 = "G40"  #: Gaszähler Größe G40
    G65 = "G65"  #: Gaszähler Größe G65
    G100 = "G100"  #: Gaszähler Größe G100
    G160 = "G160"  #: Gaszähler Größe G160
    G250 = "G250"  #: Gaszähler Größe G250
    G400 = "G400"  #: Gaszähler Größe G400
    G650 = "G650"  #: Gaszähler Größe G650
    G1000 = "G1000"  #: Gaszähler Größe G1000
    G1600 = "G1600"  #: Gaszähler Größe G1600
    G2500 = "G2500"  #: Gaszähler Größe G2500
    G4000 = "G4000"  #: Gaszähler Größe G4000
    G6500 = "G6500"  #: Gaszähler Größe G6500
    G10000 = "G10000"  #: Gaszähler Größe G10000
    G12500 = "G12500"  #: Gaszähler Größe G12500
    G16000 = "G16000"  #: Gaszähler Größe G16000
